# PlayRip

![GitHub repo size](https://img.shields.io/github/repo-size/Blackgnr7/tubedowloader?style=flat-square)
![GitHub language count](https://img.shields.io/github/languages/count/Blackgnr7/tubedowloader?style=for-the-badge)
![GitHub forks](https://img.shields.io/github/forks/Blackgnr7/tubedowloader?style=for-the-badge)
![Bitbucket open issues](https://img.shields.io/bitbucket/issues/Blackgnr7/tubedowloader?style=for-the-badge)
![Bitbucket open pull requests](https://img.shields.io/bitbucket/pr-raw/iBlackgnr7/tubedowloader?style=for-the-badge)

### Ajustes e melhorias

O projeto ainda está em desenvolvimento e as próximas atualizações serão voltadas para as seguintes tarefas:

- [x] Dowload de mp3,qualidade 320Kps, e tambem a thumbnail e o nome do artista
- [x] Ser capaz de escolher se quer em mp4 ou em mp3
- [x] dowloader automatico em qualquer sistema operacional
- [x] capaz de abaixar no spotify
- [x] ser capaz de usar em blibioteca python
- [ ] Ser capaz de instalar uma playlist inteira

## 💻 Pré-requisitos

Antes de começar, verifique se você atendeu aos seguintes requisitos:

- Você instalou a versão mais recente de `Python / Requests,eyed3,mutagen,FFmpeg,pydub,pytubefix,spotipy`
- Você tem uma máquina `Linux,Macos,Windows`.

## 🚀 Instalando TubeDowloader manualmente 

Para instalar o TubeDowloader, siga estas etapas:

```
pip install PlayRip
```

## ☕ Usando TubeDowloader

Para usar TubeDowloader para abaixar videos do youtube, siga estas etapas:

```
tubedowloader "<url-Video-youtube>" <mp4-or-mp3>
```
Para usar TubeDowloader para abaixar musicas do spotify,tem que trocar as variaves client_id e client_secret para o seu, e siga estas etapas:

```
tubedowloader "<url-musica-spotify>"
```

Adicione comandos de execução e exemplos que você acha que os usuários acharão úteis. Forneça uma referência de opções para pontos de bônus!
